package com.zjsgfa.project.zjsgfa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zjsgfa.project.zjsgfa.mapper.SjNdxmMapper;
import com.zjsgfa.project.zjsgfa.domain.SjNdxm;
import com.zjsgfa.project.zjsgfa.service.ISjNdxmService;

/**
 * 难度项目Service业务层处理
 * 
 * @author ruoyi
 * @date 2026-02-02
 */
@Service
public class SjNdxmServiceImpl implements ISjNdxmService 
{
    @Autowired
    private SjNdxmMapper sjNdxmMapper;

    /**
     * 查询难度项目
     * 
     * @param id 难度项目主键
     * @return 难度项目
     */
    @Override
    public SjNdxm selectSjNdxmById(Long id)
    {
        return sjNdxmMapper.selectSjNdxmById(id);
    }

    /**
     * 查询难度项目列表
     * 
     * @param sjNdxm 难度项目
     * @return 难度项目
     */
    @Override
    public List<SjNdxm> selectSjNdxmList(SjNdxm sjNdxm)
    {
        return sjNdxmMapper.selectSjNdxmList(sjNdxm);
    }

    /**
     * 新增难度项目
     * 
     * @param sjNdxm 难度项目
     * @return 结果
     */
    @Override
    public int insertSjNdxm(SjNdxm sjNdxm)
    {
        return sjNdxmMapper.insertSjNdxm(sjNdxm);
    }

    /**
     * 修改难度项目
     * 
     * @param sjNdxm 难度项目
     * @return 结果
     */
    @Override
    public int updateSjNdxm(SjNdxm sjNdxm)
    {
        return sjNdxmMapper.updateSjNdxm(sjNdxm);
    }

    /**
     * 批量删除难度项目
     * 
     * @param ids 需要删除的难度项目主键
     * @return 结果
     */
    @Override
    public int deleteSjNdxmByIds(Long[] ids)
    {
        return sjNdxmMapper.deleteSjNdxmByIds(ids);
    }

    /**
     * 删除难度项目信息
     * 
     * @param id 难度项目主键
     * @return 结果
     */
    @Override
    public int deleteSjNdxmById(Long id)
    {
        return sjNdxmMapper.deleteSjNdxmById(id);
    }
}
